@@ -71,40 +71,35 @@ def check_tests():
 def increment_changes():
     """increment changes"""
     version = get_version()
-    if os.path.exists(os.path.join(os.getcwd(), 'CHANGES.txt')):
-        # FIXME: Plone's CHANGES.txt (need to become a standard)
-        CHANGES = os.path.join(os.getcwd(), 'CHANGES.txt')
-        # raising the version
+    locations = (os.path.join(os.getcwd(), 'CHANGES'),
+                 os.path.join(os.getcwd(), 'CHANGES.txt'))
+    CHANGES = locations[0]
+    if not os.path.exists(CHANGES) and os.path.exists(locations[1]):
+        CHANGES = locations[1]
+
+    year = datetime.datetime.now().strftime('%Y')
+    now = datetime.datetime.now().strftime('%Y-%m-%d')
+    trunk_re = re.compile(r'^trunk \(.*\)$', re.DOTALL)
+    trunk_line = 'trunk (%s)' % now
+    bootstrap = [trunk_line, len(trunk_line) * '=', '', 
+                 '  - xxx [Ingeniweb]', '']
+
+    if os.path.exists(CHANGES):
         content = open(CHANGES).read()
-        if '%s (20' % version not in content:
-            content = content.replace('trunk (20', '%s (20' % version)
-            now = datetime.datetime.now().strftime('%Y-')
-            content = ['trunk (%sxx-xx)' % now,
-                       '==================',
-                       '',
-                       '  - xxx [Ingeniweb]',
-                       ''] + content.split('\n')
-        else:
-            content = content.split('\n')
+        # let's replace the trunk with the current version and date
+        version_line = '%s (%s)' % (version, now)
+        underline = len(version_line) * '='
+        content = content.split('\n')
+        for index, line in enumerate(content):
+            if trunk_re.match(line):
+                content[index] = version_line
+                content[index+1] = underline
+                break
+        content = bootstrap + content
     else:
-        # FIXME: IW CHANGES (need to use the Plone standard instead)
-        CHANGES = os.path.join(os.getcwd(), 'CHANGES')
-        if not os.path.exists(CHANGES):
-            # no CHANGES file, let's create it
-            content = ['* trunk',
-                       '  - ',
-                       '',
-                       '* %s' % version,
-                       '  - initial revision',
-                       '']
-        else:
-            # raising the version
-            content = open(CHANGES).read()
-            if '* %s' % version not in content:
-                content = content.replace('* trunk', '* %s' % version)
-                content = ['* trunk',  '  -'] + content.split('\n')
-            else:
-                content = content.split('\n')
+        # no CHANGES file, let's create it
+        content = bootstrap
+        
     f = open(CHANGES, 'wb')
     try:
         f.write('\n'.join(content))
